"""
Tests for vela.emulators
"""
import os
from unittest.mock import patch, mock_open

import pytest

from vela.emulators import CalibrationEmulator, ImagingEmulator
from vela.forger import forge


class TestCalibrationEmulator:
    @pytest.mark.skip("Ignores forger mock.")
    @patch("os.chdir")
    @patch("vela.forger.VelaProduct.forge_products")
    @patch("vela.forger.VelaLog.forge_logs")
    def test_run(self, mock_logs, mock_products, mock_os):
        with patch("vela.forger.forge") as mock_forge:
            CalibrationEmulator("test/test.json", "test/PPR.xml").run()
            assert mock_forge.call_count == 1

    def test_setup_environment(self):
        parameters = {
            "useCasa": False,
            "homeForReprocessing": "/home/casa/packages/pipeline/current",
            "rootDirectory": "/tmp/workspaces_tmp/",
        }
        CalibrationEmulator("test.json", "PPR.xml").setup_environment(parameters=parameters)
        assert os.environ.get("SCIPIPE_ROOTDIR") == parameters["rootDirectory"]
        assert os.environ.get("CASA_HOME") == parameters["homeForReprocessing"]
        assert os.environ.get("PPR_FILENAME") == "PPR.xml"

    @patch("glob.glob")
    @patch("os.chdir")
    def test_check_logs(self, mock_os, mock_glob):
        with patch("builtins.open", mock_open()) as o:
            CalibrationEmulator("test.json", "PPR.xml").check_logs(parent_path=mock_os)
            assert o.call_count == 0
            assert mock_os.call_count == 1
            assert mock_glob.call_count == 1


class TestImagingEmulator:
    @pytest.mark.skip("Ignores forger mock.")
    @patch("os.chdir")
    @patch("vela.forger.VelaProduct.forge_products")
    @patch("vela.forger.VelaLog.forge_logs")
    def test_run(self, mock_logs, mock_products, mock_os):
        with patch("vela.forger.forge") as mock_forge:
            ImagingEmulator("test/test.json", "test/PPR.xml").run()
            assert mock_forge.call_count == 1

    def test_setup_environment(self):
        parameters = {
            "useCasa": False,
            "homeForReprocessing": "/home/casa/packages/pipeline/current",
            "rootDirectory": "/tmp/workspaces_tmp/",
        }
        ImagingEmulator("test.json", "PPR.xml").setup_environment(parameters=parameters)
        assert os.environ.get("SCIPIPE_ROOTDIR") == parameters["rootDirectory"]
        assert os.environ.get("CASA_HOME") == parameters["homeForReprocessing"]
        assert os.environ.get("PPR_FILENAME") == "PPR.xml"

    @patch("glob.glob")
    @patch("os.chdir")
    def test_check_logs(self, mock_os, mock_glob):
        with patch("builtins.open", mock_open()) as o:
            ImagingEmulator("test.json", "PPR.xml").check_logs(parent_path=mock_os)
            assert o.call_count == 0
            assert mock_os.call_count == 1
            assert mock_glob.call_count == 1
